      subroutine vvskk(u1,n1,p1,u2,n2,p2,u,n,p,g,mass,wdth)
c----------------------------------------------------------------------c
c Returns a scalar array being a contraction of a triple vector-scalar 
c boson vertex with two polarization vectors
c
c Input: u1,u2 - vector arrays,
c        n1,n2,n - numbers of polarization states,
c        p1,p2 - momenta,
c        g - a triple scalar-vector boson coupling,
c        mass, wdth - mass and width of u.
c Output: u - scalar array,
c         p - its momentum.
c All four momenta are cosidered as incoming to the vertex.
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 17 May, 2007 (based on vvhkk.f); modified on 
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: n1,n2,n,i1,i2,i

      real(dp) :: mass,wdth
      real(dp), dimension(0:3) :: p1,p2,p
      complex(dp) :: u1(0:3,n1),u2(0:3,n2),u(1,n),g,gden

      p=-p1-p2

      gden=g/cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2-mass**2,mass*wdth,dp)

      i=0
      do i2=1,n2
       do i1=1,n1
         i=i+1
         u(:,i)=gden*(u1(0,i1)*u2(0,i2)-u1(1,i1)*u2(1,i2)
     &               -u1(2,i1)*u2(2,i2)-u1(3,i1)*u2(3,i2))
       end do
      end do

      end subroutine vvskk
